@@ -19,10 +19,12 @@ except ImportError:
 
 try:
     from polars import DataFrame as _pl_DataFrame
+    from polars import LazyFrame as _pl_LazyFrame
 except ImportError:
     _pl_DataFrame = None
+    _pl_LazyFrame = None
 
-DataFrame = TypeVar('DataFrame', _pl_DataFrame, _pd_DataFrame)
+DataFrame = TypeVar('DataFrame', _pl_LazyFrame, _pl_DataFrame, _pd_DataFrame)
 
 # ===============================
 # TypeError: expecting bool or Boolean, not `ts_delay(X, 3)`.
@@ -127,11 +129,12 @@ class ExprTool:
 
         exprs_dict = {}
 
-        # 不做改动，直接生成
+        # cse前简化一次，cse后不再简化
+        # (~开盘涨停 & 昨收涨停) | (~收盘涨停 & 最高涨停)
         for variable, expr in repl:
-            exprs_dict[variable] = simplify2(expr)
+            exprs_dict[variable] = expr
         for variable, expr in redu:
-            exprs_dict[variable] = simplify2(expr)
+            exprs_dict[variable] = expr
 
         return exprs_dict
 
@@ -322,6 +325,8 @@ def codegen_exec(df: Optional[DataFrame],
         ^ 转成异或还是乘方
     style: str
         代码风格。可选值 'pandas', 'polars_group', 'polars_over'
+        - polars_group: 不支持Lazy
+        - pandas: 不支持struct
     template_file: str
         代码模板
     date: str
